---
name: Issue report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Before you open an issue**
Please make sure you've upgraded to the latest version of kobodl on [pypi](https://pypi.org/project/kobodl/) or [docker](https://hub.docker.com/r/subdavis/kobodl)

**Describe the issue**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g.  MacOS]
-  Install method and python version: [eg. docker, python 3.9]
 - Kobodl Version [e.g. 0.6.0]

**Additional context**
Add any other context about the problem here.
